pub fn compute_segments_root<'a, const MAX_SEGMENTS: u64, Iter>(
segment_roots: Iter,
) -> Blake3HashExpand description
Calculates a Merkle Tree root for a provided list of segment roots
pub fn compute_segments_root<'a, const MAX_SEGMENTS: u64, Iter>(
segment_roots: Iter,
) -> Blake3HashCalculates a Merkle Tree root for a provided list of segment roots